/*
 * CIS.java
 *
 * Created on October 11, 2004, 1:48 AM
 */

package university;

import  java.util.ArrayList;
/**
 * Class for the CIS department in the university.
 * Uses the sigleton patterns so only one instance can be created
 *
 * @author  Nathan Balon
 * University Application
 * CIS 550 - Object Oriented Programming
 * U 0f M Dearborn
 * November 7, 2004
 * @version 1.0
 */

public class CIS extends Education{
    
    /** Creates a new instance of CIS */
    private CIS() {
        super();
        progLanguagesTaught = new ArrayList<String>();
    }
    
    /** Creates a new instance of CIS */   
    private CIS(String name, Address address){
        super(name, address);
        progLanguagesTaught = new ArrayList<String>();
    }
    
    /**
     * Returns the unit
     * @return Unit the unit
     */
    public static Unit getInstance(){
        return cis;
    }
  
    /**
     * Creates a new CIS unit.
     * @param name  The name of the unit
     * @param address The address of the unit
     * @return Unit that was ceated
     */
    public synchronized static Unit create(String name, Address address){
        if(cis == null){
            cis = new CIS(name, address);
        }
        return cis;
    }
    
    /** Adds a programming language to those taught by the CIS department
     *  @param programmingLanguage The name of the new programming language
     */
    public final void addLanguage(String programmingLanguage){
        progLanguagesTaught.add(programmingLanguage);
    }
    
    /** Returns an array of the programming languages taught by the CIS department 
     *  @return an array of the programming languages taught 
     */
    public final String[] getLanguages(){
        return (String[])progLanguagesTaught.toArray();
    }
    
    /** Returns a String representation of the CIS unit
     *  @return String representing CIS
     */
    public String toString(){
        String out = super.toString();
        for(int i = 0; i < progLanguagesTaught.size(); i++){
            // if first element add a title
            if(i == 0){
                out += ", Languages Taught: [";
            }
            out += " " + progLanguagesTaught.get(i);
            // if not the last entry print a comma
            if(i + 1 != progLanguagesTaught.size()){
                out += ", ";
            }
            else{
                out += " ] ";
            }
        }
        return out;
    }
    
    private ArrayList <String> progLanguagesTaught;     // programming laguages taught
    private static CIS cis;                             // Instace of the CIS Unit
}
