/*
 * DirectoryFacade.java
 *
 * Created on November 1, 2004, 10:57 PM
 */

package university;

import java.io.Serializable;
import java.io.*;
import java.util.regex.*;

/**
 * Facade to inteface with the Unit and University Directory.
 * @author  Nathan Balon
 * University Application
 * CIS 550 - Object Oriented Programming
 * U 0f M Dearborn
 * November 7, 2004
 * @version 1.0
 */


public class DirectoryFacade implements Cloneable, Serializable, Directory{
    
    /** Creates a new instance of DirectoryFacade */
    public DirectoryFacade() {
        unitDirectory = new UnitDirectory();
        categoryDirectory = new CategoryDirectory() ;
    }
    
    /**
     * Creates a new instance of the DirectoryFacade
     * @param directory a DirectoryFacade to make a copy of.
     */
    public DirectoryFacade(DirectoryFacade directory){
        try{
            unitDirectory = (UnitDirectory)directory.getUnitDirectory().clone();
            categoryDirectory = (CategoryDirectory)directory.getCategoryDirectory().clone();
        }
        catch(java.lang.CloneNotSupportedException e){
            System.err.println("Error cloning the directory");
            e.printStackTrace();
        }
    }
    
    /**
     * Clone a new Directoryfacade object
     * @throws java.lang.CloneNotSupportedException Throws CloneNotSupportedException
     * @return Object a cloned object
     */    
    @Override
    public Object clone() throws java.lang.CloneNotSupportedException{
        DirectoryFacade cloned = (DirectoryFacade)super.clone();
        cloned.categoryDirectory = (CategoryDirectory)categoryDirectory.clone();
        cloned.unitDirectory = (UnitDirectory)unitDirectory.clone();
        return cloned;
    }    
    
    
    
    /**
     *  Add a Person to the UniversityDirectory 
     *  @param person The person to add to the UniversityDirectory
     */
    public void add(Person person){
        unitDirectory.add(person);
        categoryDirectory.add(person);
    }
    
    /** 
     *  Remove a Person from the UniversityDirectory.
     *  @param person The person to remove from the UniversityDirectory
     */
    public void remove(Person person){
        unitDirectory.remove(person);
        categoryDirectory.remove(person);
    }

    /**
     * List all people in the directory.
     * @return String with a list of all people in the directory.
     */
    public String listAll(){
        String directoryList = "\n\t\tUniversity Directory\n" +
        "------------------------------------------------------" +
        "------------------------------------\n" +
        unitDirectory.listAll();
        return directoryList;
    }
    
    /**
     * Search for a Person by name.
     * @param name the name of the Person
     * @return the person
     */
    public Person search(String name){
        Person person = unitDirectory.search(name);
        return person;
    }

    /**
     * Search for a Person by ID.
     * @param id the ID number of the Person
     * @return the person
     */    
    public Person search(int id){
        Person person = unitDirectory.search(id);
        return person;
    } 
    
     /**
     * Search for a Person, reads in input from the console then finds
     * the Person in the directory.
     * @return Person found in the directory or null if not found.
     */  
    public Person search(){
        System.out.print("Enter the Name or ID to search for: "); 
        Person person = null;
            try{
            // read the user choice from the console
            BufferedReader console = new BufferedReader(new InputStreamReader(System.in));      
            String choice = console.readLine();
            // check if a number was entered
            Pattern p = Pattern.compile("[0-9]+");
            Matcher m = p.matcher(choice);
            boolean isNumber = m.matches();
            if(isNumber){
                // if a number was entered search for the person by number
                int id = Integer.parseInt(choice);
                person = search(id);
            }else{
                // else search for the person by  name
                person = search(choice);
            }
        } 
        catch(IOException e){
            e.printStackTrace();
        }  
        return person; 
    }
    
  
     /**
     * Get the size of all the units and categories of people in the directory.
     * @return String list the size of the units and categories
     */        
    public String size(){
            String listSize =  "\n\t\tDirectory Sizes\n" +
            "--------------------------------------------------------------\n\n" +
            "\t\tUnit Categories\n" +
            "--------------------------------------------------------------\n" +
            unitDirectory.size() +  
            "\n\t\tPerson Categories\n" + 
            "--------------------------------------------------------------\n" + 
            categoryDirectory.size();        
            return listSize;
    }
    
    public String displayUnit(){
        System.out.println();
        Menu.displayUnitMenu();
        System.out.print("\nSelect the unit: ");
        int selection = 0;
        boolean validSelection = false;
        try{
            BufferedReader console = new BufferedReader(new InputStreamReader(System.in));
            while(!validSelection){
                // check if input is valid
                String choice = console.readLine();
                Pattern p = Pattern.compile("[1-4]");
                Matcher m = p.matcher(choice);
                boolean isNumber = m.matches();
                if(isNumber){
                    // if input is valid parse it
                    selection = Integer.parseInt(choice);
                    validSelection = true;
                } 
                else{
                    System.out.println("Invalid input");
                }
            }
            System.out.println();
            return unitDirectory.displayUnit(selection);
        } catch(IOException e){
            e.printStackTrace();
        }
        return null;
    }
    
    /**
     * Display all the people of a certain category.
     * @return String A String listing all people in a category.
     */
    public String displayCategory(){
        System.out.println();
        Menu.displayPersonMenu();
        System.out.print("Select the category: ");
      
        int selection = 0;
        boolean validSelection = false;
        try{
            BufferedReader console = new BufferedReader(new InputStreamReader(System.in));    
            while(!validSelection){
                // check if input is valid
                String choice = console.readLine();
                Pattern p = Pattern.compile("[1-4]");
                Matcher m = p.matcher(choice);
                boolean isNumber = m.matches();
                if(isNumber){
                    // if input is valid parse it
                    selection = Integer.parseInt(choice);
                    validSelection = true;
                } 
                else{
                    System.out.println("Invalid input");
                }
            }
            System.out.println();  
            return categoryDirectory.displayCategory(selection);
        } 
        catch(IOException e){
            e.printStackTrace();
        }
        return null;
    }
    
    // return the unitDirectory for the constructor
    private UnitDirectory getUnitDirectory(){
        return unitDirectory;
    }
    
    // return the categoryDirectory for the copy constructor
    private CategoryDirectory getCategoryDirectory(){
        return categoryDirectory;
    }

    private UnitDirectory unitDirectory;                // a directory of units
    private CategoryDirectory categoryDirectory;        // a directory of categories


}
