/*
 * PersonAdapterImpl.java
 *
 * Created on November 11, 2004, 10:19 PM
 */

package university;

import java.rmi.server.UnicastRemoteObject;
import java.rmi.*;

/**
 * Adapter Class for the purpose of using People from the university as remote objects
 *
 * @author  Nathan Balon
 * University Application
 * CIS 550 - Object Oriented Programming
 * U 0f M Dearborn
 * November 7, 2004
 * @version 1.0
 */

public class PersonAdapterImpl extends UnicastRemoteObject implements PersonAdapter{
    
    /** Creates a new instance of PersonAdapterImpl
     *  @param p the person object to be used by the adapter.
     */
    public PersonAdapterImpl(Person p) throws RemoteException{
        person = p;
    }
    
     /**
     * Returns the name of a person
     * @return The name of the person
     */
    public String getName()throws RemoteException{
        return person.getName();
    }
    
     /**
     * Set the persons name to a new name.
     * @param name The name of the person.
     */  
    public void setName(String name) throws RemoteException{
        person.setName(name);
    }
    
    /**
     * Returns the sex of a person
     * @return The gender of the person
     */
    public Sex getGender()throws RemoteException{
        return person.getGender();
    }
    
    /**
     * Returns the unit a person belongs to.
     * @return The unit that the person belongs to
     */
    public Unit getAffiliation() throws RemoteException{
        return person.getAffiliation();
    }
    
    /**
     * Returns the ID of a person.
     * @return The ID of the person
     */
    public int getID()throws RemoteException{
        return person.getID();
    }

    /**
     * Get the Address of the Person.
     * @return The Address of the Person.
     */
    public Address getAddress()throws RemoteException{
        return person.getAddress();
    }

    /**
     * Get a description of the Person.
     * @return A String representing a Person.
     */    
    public String printDescription() throws RemoteException{
        return person.toString();
    }
    
    private Person person;       
}
