/*
 * BuildPerson.java
 *
 * Created on October 21, 2004, 4:43 PM
 */

package university;

import java.io.*;
import java.util.regex.*;

/**
 * Abstract Factory Class to build the person infromation from commands entered 
 * from the console.
 *
 * @author  Nathan Balon
 * University Application
 * CIS 550 - Object Oriented Programming
 * U 0f M Dearborn
 * November 7, 2004
 * @version 1.0
 */
public abstract class PersonFactory {
    
    /** Creates a new instance of BuildPerson */
    public PersonFactory() {

    }
    
    /** Builds the person infromation from the console input */
    protected void buildPersonInfo(){
        console = new BufferedReader(new InputStreamReader(System.in));
        String sex = "";
        int unitChoice = 0;
        try{
            // get the persons name
            System.out.print("What is the name? ");
            name = console.readLine();
            // get the persons sex
            while(!sex.startsWith("f") && !sex.startsWith("m")){
                System.out.print("Gender (m or f)? ");
                sex = console.readLine();
            }
            if(sex.toLowerCase().startsWith("f")){
                gender = Sex.FEMALE;
            }
            else{
                gender = Sex.MALE;
            }
            
            while((unitChoice < 1) || (unitChoice > 5)){
                Menu.displayUnitMenu();
                System.out.print("\nEnter the unit belonged to: ");
                String input = console.readLine();            
                // check that the input is a number
                Pattern p = Pattern.compile("[1-5]");
                Matcher m = p.matcher(input);
                boolean isNumber = m.matches();
                if(isNumber){
                    unitChoice = Integer.parseInt(input);
                }else{
                    System.out.println("Invalid input");
                }
           }
            switch(unitChoice){
                case 1:
                    unit = CIS.getInstance();
                    break;
                case 2:
                    unit = Education.getInstance();
                    break;
                case 3:
                    unit = Library.getInstance();
                    break;
                case 4:
                    unit = HR.getInstance();
                    break;
                case 5:
                    unit = Addmissions.getInstance();
                    break;
                default:
                    System.err.println("Error: invalid Unit selection");
           }
           System.out.println("Enter your address inforamtion.");
           address = AddressFactory.build();

        }
        catch(IOException e){
            System.err.println("Error: Invalid input.");
        }
    }
    
     /**
     * createPerson call the correct builder based on the choice
     * @return Person The newly created person.
     */    
    public static Person createPerson(){
        Build b;
        Person p;
        int choice = 0;
        boolean isNumber = false;
        System.out.println("\nAdding a Person!! enter some more info:");  
        while(!isNumber){      
            Menu.displayPersonMenu();
            System.out.print("$ ");
            try{
                BufferedReader console = new BufferedReader(new InputStreamReader(System.in));
                String input = console.readLine();
                Pattern pattern = Pattern.compile("[1-4]");
                Matcher m = pattern.matcher(input);
                isNumber = m.matches();
                if(isNumber){
                    choice = Integer.parseInt(input);
                }else{
                    System.out.println("Invalid input");
                }   
            }
            catch(Exception e){
                e.printStackTrace();
            }
        }
        switch(choice){
            case 1:
                System.out.println("Creating new Staff member.");
                b = new StaffFactory();
                p = b.build();   
                return p;
            case 2:
                System.out.println("Creating new Faculty member.");               
                b = new FacultyFactory();
                p = b.build();
                return p;  
            case 3:
                System.out.println("Creating new Undegraduate student.");
                b = new UndergraduateFactory();
                p = b.build();   
                return p;
            case 4:
                System.out.println("Creating new Graduate student.");
                b = new GraduateFactory();
                p = b.build();   
                return p;                
        }
        return null;
    }
    
    protected Unit unit;            // unit the person belongs to    
    protected String name;          // name of the person
    protected Address address;
    protected Sex gender;           // gender of the person
    protected BufferedReader console;
}
