/*
 * PersonListImpl.java
 *
 * Created on November 10, 2004, 12:18 PM
 */

package university;

import java.rmi.*;
import java.rmi.server.UnicastRemoteObject;
import java.util.Vector;

/**
 * PersonListImpl is the server portion of the RMI program that adds a
 * PersonAdapter to a list of people.
 *
 * @author  Nathan Balon
 * University Application
 * CIS 550 - Object Oriented Programming
 * U 0f M Dearborn
 * November 7, 2004
 * @version 1.0
 */

public class PersonListImpl extends java.rmi.server.UnicastRemoteObject implements PersonList{
    
    /** Creates a new instance of PersonListImpl */
    public PersonListImpl() throws RemoteException{
        theList = new Vector<PersonAdapter>();
    }
    
    /**
     * Adds a person to the remote directory.
     * @param person The person to be added to the list.
     */
    public void addPerson(PersonAdapter person) throws RemoteException{
        // add the person to the list
        theList.addElement(person);     
        System.out.println("\nServer: Added a new person to the list\n");
        // print the description of the person added
        System.out.println(person.printDescription());
    }
    
    /**
     * Remove a person to the remote directory.
     * @param ID The ID number of the person to be removed from the list.
     */    
    public void removePerson(int ID) throws RemoteException{
        for(int i = 0; i < theList.size(); i++){
            PersonAdapter person = theList.get(i);
            if(person.getID() == ID){
                theList.remove(i);
            }
        }
    }
    
    /**
     *  Lists all people that are contained in the remote directory.
     *  @return String a string listing all people in the list.
     */
    public String ListAll() throws RemoteException{
        int i;
        String printstring = " ";
        System.out.println("Server: displaying the list of people\n");
        // add all people in the directory to a list
        if(theList.size() > 0){
            for (i=0; i<theList.size(); i++){
                // get the person from the list and display their information
                PersonAdapter person = (PersonAdapter)theList.elementAt(i);            
                if(person != null){
                    printstring += person.printDescription();
                    printstring += "\n";
                }
            }
        } else {
            // return that the list is empty
            printstring = "Empty List\n";
        }
        // diplay the list on the server.
        System.out.println("\t\tList of all people in the remote list");
        System.out.println("-----------------------------------" +
                         "-----------------------------------");
        System.out.println(printstring);
        // return the list to the client
        return printstring;         
    }
    
    /** 
     *  Main entry point to the server application.
     */
    public static void main(String [] args){
        try{
            String name = "//localhost/PersonList";
            System.out.println("Registering PersonListImpl as " + name);
            // create a new list
            PersonListImpl list = new PersonListImpl();
            // bind the list in the registry
            Naming.rebind(name, list);
            System.out.println("Remote list bound to registry");
        }
        catch(Exception e){
            System.err.println("Exception while binding list " + e);
        }
    }
    
    private Vector <PersonAdapter> theList;             // list of people
}
